@@ -122,7 +122,7 @@ def _update_save_default_args(save_base, session):
 
 
 def save_base(plot, save_path, file_exists_mode, width_total_as_session,
-              share_x, share_y):
+              share_x, share_y, get_html_only):
     if not save_path:
         # TODO: Add warning
         return None
@@ -171,7 +171,8 @@ def format_color(col):
 
 def is_iterable(obj):
     ''' Check if an object is iterable
-    Cf https://stackoverflow.com/questions/1952464/in-python-how-do-i-determine-if-an-object-is-iterable
+    Cf https://stackoverflow.com/questions/1952464/in-python-how-do-i- \
+    determine-if-an-object-is-iterable
 
     Args:
         obj (Any object)
